﻿#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2011 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion

using System.Windows.Forms;
using HeuristicLab.Core;
using HeuristicLab.Data;
using HeuristicLab.MainForm;

namespace HeuristicLab.Problems.DataAnalysis.Views {
  [View("TimeSeriesPrognosisnSolution View")]
  [Content(typeof(TimeSeriesPrognosisSolutionBase), false)]
  public partial class TimeSeriesPrognosisSolutionView : DataAnalysisSolutionView {
    public TimeSeriesPrognosisSolutionView() {
      InitializeComponent();
    }

    public new TimeSeriesPrognosisSolutionBase Content {
      get { return (TimeSeriesPrognosisSolutionBase)base.Content; }
      set { base.Content = value; }
    }

    protected override void OnContentChanged() {
      base.OnContentChanged();
      if (Content != null) {
        horizonTextBox.Text = Content.Horizon.ToString();
      }
    }

    #region drag and drop
    protected override void itemsListView_DragEnter(object sender, DragEventArgs e) {
      validDragOperation = false;
      if (ReadOnly) return;

      var dropData = e.Data.GetData(HeuristicLab.Common.Constants.DragDropDataFormat);
      if (dropData is TimeSeriesPrognosisProblemData) validDragOperation = true;
      else if (dropData is IValueParameter) {
        var param = (IValueParameter)dropData;
        if (param.Value is TimeSeriesPrognosisProblemData) validDragOperation = true;
      }
    }
    #endregion

    private void horizonTextBox_Validating(object sender, System.ComponentModel.CancelEventArgs e) {
      int val;
      if (int.TryParse(horizonTextBox.Text, out val)) {
        e.Cancel = val <= 0 || val >= Content.ProblemData.TrainingPartition.End - Content.ProblemData.TrainingPartition.Start;
      } else {
        e.Cancel = true;
      }
    }

    private void horizonTextBox_Validated(object sender, System.EventArgs e) {
      int val;
      int.TryParse(horizonTextBox.Text, out val);
      Content.Horizon = val;
    }
  }
}
